# HDR

<p>This command is used to construct an HDR bearing element object in
three-dimension. The 3D continuum geometry of an high damping rubber
bearing is modeled as a 2-node, 12 DOF discrete element. This is the
third element in the series of elements developed for analysis of
base-isolated structures under extreme loading (others being <a
href="ElastomericX" title="wikilink">ElastomericX</a> and <a
href="LeadRubberX" title="wikilink">LeadRubberX</a>). The major
difference between HDR element with <a href="ElastomericX"
title="wikilink">ElastomericX</a> is the hysteresis model in shear. The
HDR element uses a model proposed by Grant et al. (2004) to capture the
shear behavior of a high damping rubber bearing. The time-dependent
values of mechanical properties (e.g., vertical stiffness, buckling load
capacity) can also be recorded using the "parameters" <a
href="#Recorders" title="wikilink">recorder</a>.</p>
<p>For a 3D problem:</p>

```tcl
element HDR $eleTag $Nd1 $Nd2 $Gr $Kbulk $D1 $D2 $ts $tr
        $n $a1 $a2 $a3 $b1 $b2 $b3 $c1 $c2 $c3 $c4 &lt;&lt;$x1 $x2 $x3&gt; $y1
        $y2 $y3&gt; &lt;$kc&gt; &lt;$PhiM&gt; &lt;$ac&gt; &lt;$sDratio&gt;
        &lt;$m&gt; &lt;$tc&gt;
```

<hr />
<table>
<tbody>
<tr class="odd">
<td><code class="parameter-table-variable">eleTag</code></td>
<td><p>unique element object tag</p></td>
</tr>
<tr class="even">
<td><p><code class="parameter-table-variable">Nd1 Nd2</code></p></td>
<td><p>end nodes</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Gr</code></td>
<td><p>shear modulus of elastomeric bearing</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Kbulk</code></td>
<td><p>bulk modulus of rubber</p></td>
</tr>
<tr class="odd">
<td><p><code class="parameter-table-variable">D1</code></p></td>
<td><p>internal diameter</p></td>
</tr>
<tr class="even">
<td><p><code class="parameter-table-variable">D2</code></p></td>
<td><p>outer diameter (excluding cover thickness)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">ts</code></td>
<td><p>single steel shim layer thickness</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">tr</code></td>
<td><p>single rubber layer thickness</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">n</code></td>
<td><p>number of rubber layers</p></td>
</tr>
<tr class="even">
<td><p><strong>$a1 $a2 $a3 $b1 $b2 $b3 $c1 $c2 $c3 $c4</strong></p></td>
<td><p>parameters of the Grant model</p></td>
</tr>
<tr class="odd">
<td><p><code class="parameter-table-variable">x1 x2 x3</code></p></td>
<td><p>vector components in global coordinates defining local x-axis
(optional)</p></td>
</tr>
<tr class="even">
<td><p><code class="parameter-table-variable">y1 y2 y3</code></p></td>
<td><p>vector components in global coordinates defining local y-axis
(optional)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">kc</code></td>
<td><p>cavitation parameter (optional, default = 10.0)</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">PhiM</code></td>
<td><p>damage parameter (optional, default = 0.5)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">ac</code></td>
<td><p>strength reduction parameter (optional, default = 1.0)</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">sDratio</code></td>
<td><p>shear distance from iNode as a fraction of the element length
(optional, default = 0.5)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">m</code></td>
<td><p>element mass (optional, default = 0.0)</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">tc</code></td>
<td><p>cover thickness (optional, default = 0.0)</p></td>
</tr>
</tbody>
</table>
<h2 id="physical_model_and_mechanical_properties">Physical Model and
Mechanical Properties</h2>
<p>The physical model is considered as a two-node, twelve
degrees-of-freedom discrete element. The two nodes are connected by six
springs that represent the mechanical behavior in the six basic
directions of a bearing. The degrees of freedom and discrete spring
representation of an elastomeric bearing is shown in the below
figures.</p>
<p><img src="/OpenSeesRT/contrib/static/Elastomeric3DModel.png"
title="inline|Physical continuum model" height="300"
alt="inline|Physical continuum model" /> <img
src="/OpenSeesRT/contrib/static/ElastomericDiscreteSpring.png"
title="inline|Discrete spring representation" height="300"
alt="inline|Discrete spring representation" /></p>
<p>The general form of element force vector, $$,
and element stiffness matrix,&lt;math&gt;&lt;/math&gt; , for element
representation considered above is given by equation below:</p>
<p>&lt;math&gt;=\left[ \begin{matrix} Axial \\ Shear1 \\ Shear2 \\
Torsion \\ Rotation1 \\ Rotation2 \\ \end{matrix} \right];\ \ \ \ \ \
=\left[ \begin{matrix} Axial &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\
0 &amp; Shear1 &amp; Shear12 &amp; 0 &amp; 0 &amp; 0 \\ 0 &amp; Shear21
&amp; Shear2 &amp; 0 &amp; 0 &amp; 0 \\ 0 &amp; 0 &amp; 0 &amp; Torsion
&amp; 0 &amp; 0 \\ 0 &amp; 0 &amp; 0 &amp; 0 &amp; Rotation1 &amp; 0 \\
0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; Rotation2 \\ \end{matrix}
\right]&lt;/math&gt;</p>
<p>The coupling of the two shear springs is considered directly by using
a coupled bidirectional model. All other springs are uncoupled. The
coupling of vertical and horizontal directions are considered indirectly
by using expressions for mechanical properties in one direction that are
dependent on the response parameters in the other direction. Linear
uncoupled springs are considered in the torsion and the two rotational
springs as they are not expected to significantly affect the response of
an elastomeric bearing. The off-diagonal terms due to coupling between
axial and shear, and axial and rotation, are not considered in the
two-spring model (Koh and Kelly, 1987) used here. An exact model would
have non-zero values of these off-diagonal terms. A discussion on the
formulation of the two-spring model and the exact model is presented in
Ryan et al.(1991). The subscript b refers to the element’s basic
coordinate system. Response quantities are transformed between the
basic, local and global coordinates to perform computations.</p>
<p>The discrete spring model presented here has the advantages of easy
implementation and being computationally efficient. The mechanical
properties of the six springs (also referred to as material models in
OpenSees) are defined using analytical solutions available from the
analysis of elastomeric bearings. The expression for mechanical
properties, including stiffness and buckling load capacity, are derived
using explicit consideration for geometric nonlinearity due to large
displacement effects. The P-Delta effect, which is an approximate method
to account for geometric nonlinearity in structural analysis problems,
is therefore not considered. The material models in six directions
are:</p>
<ul>
<li>Axial direction: a new mathematical model that captures the behavior
under cyclic tension <a
href="http://onlinelibrary.wiley.com/doi/10.1002/eqe.2431/abstract">Link</a></li>
<li>Two shear directions: a bidirectional model proposed by Grant et al.
(2004)</li>
<li>Torsion: a linear elastic model</li>
<li>Two rotational directions: linear elastic models</li>
</ul>
<p>In addition to the behavior captured by existing bearing elements,
this element can capture the following:</p>
<ol>
<li>Degradation of bearing stiffness and damping due to scragging
effects in shear</li>
<li>Cavitation and post-cavitation behavior in tension</li>
<li>Variation in critical buckling load capacity due to lateral
displacement</li>
<li>Variation in vertical axial stiffness with horizontal
displacement</li>
</ol>
<h2 id="recorders">Recorders</h2>
<p>In addition to regular recorders provided by the bearing elements (<a
href="Element_Recorder" title="wikilink"> Element Recorder</a>), this
element can also record instantaneous values of cavitation force (Fcn),
buckling load capacity (Fcrn), and vertical stiffness (Kv) using the
"Parameters" recorder in that order.</p>
<p>Example: recorder Element &lt;-file $fileName&gt; -time &lt;-ele
($ele1 $ele2 ...)&gt; Parameters recorder Element -file param.out -time
-ele 1 Parameters</p>
<p>To check if bearing has buckled or cavitated, an user can obtain the
histories of Fcn and Fcrn as described above and divide the axial force
(obtained from basicForce recorder, qb(2)) by Fcn and Fcrn at each time
step, which provides demand vs capacity (D/C) ratios at each time step.
If Fcn/qb(0) &gt; 1.0 : Cavitation, or Fcrn/qb(0)&gt;1.0 : Buckling.</p>
<h2 id="examples">Examples</h2>
<p>An example is presented here, in which a high damping rubber bearing
(bearing KL301 in Grant et al. (2004)) is subjected to different
amplitudes and sequences of loading. The bearing (KL301) and parameters
of Grant's model presented in Grant et al. (2004) have been used. The
tcl files can be found here: <embed src="HDRgravity.tcl"
title="HDRgravity.tcl" /> <embed src="HDRtest.tcl"
title="HDRtest.tcl" /></p>
<p><img src="/OpenSeesRT/contrib/static/Strain50.png" title="inline|50% Strain" height="300"
alt="inline|50% Strain" /> <img src="/OpenSeesRT/contrib/static/Strain100.png"
title="inline|100% Strain" height="300" alt="inline|100% Strain" /> <img
src="/OpenSeesRT/contrib/static/Strain200.png" title="inline|200% Strain" height="300"
alt="inline|200% Strain" /><img src="/OpenSeesRT/contrib/static/StrainIT.png"
title="inline|increasing triangular" height="300"
alt="inline|increasing triangular" /></p>
<h2 id="references">References</h2>
<ol>
<li>Kumar, M., Whittaker, A., and Constantinou, M. (2014). "An advanced
numerical model of elastomeric seismic isolation bearings." Earthquake
Engineering &amp; Structural Dynamics, Published online, DOI:
10.1002/eqe.2431. <a
href="http://onlinelibrary.wiley.com/doi/10.1002/eqe.2431/abstract">Link</a></li>
<li>Grant, D. N., Fenves, G. L., and Whittaker, A. S. (2004).
"Bidirectional modeling of high-damping rubber bearings." Journal of
Earthquake Engineering, 8(sup001), 161-185.</li>
<li>Kumar, M., Whittaker, A., and Constantinou, M. (2015). "Experimental
investigation of cavitation in elastomeric seismic isolation bearings."
Engineering Structures, 101, 290-305. <a
href="http://www.sciencedirect.com/science/article/pii/S0141029615004575">Link</a></li>
<li>Kumar, M., Whittaker, A., and Constantinou, M. (2015). "Response of
base-isolated nuclear structures to extreme earthquake shaking." Nuclear
Engineering and Design (In press). <a
href="http://www.sciencedirect.com/science/article/pii/S002954931500254X">Link</a></li>
</ol>
<hr />
<p>Code Developed by: <span style="color:blue"> Manish Kumar,
University at Buffalo, SUNY. </span></p>
<p>Any bugs in this element can be reported to mkumar2 AT buffalo dot
edu</p>
