# HyperbolicGapMaterial

<p>This command is used to construct a hyperbolic gap material
object.</p>

```tcl
uniaxialMaterial HyperbolicGapMaterial $matTag $Kmax $Kur
        $Rf $Fult $gap
```
<hr />
<table>
<tbody>
<tr class="odd">
<td><code class="parameter-table-variable">matTag</code></td>
<td><p>integer tag identifying material</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Kmax</code></td>
<td><p>initial stiffness</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Kur</code></td>
<td><p>unloading/reloading stiffness</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Rf</code></td>
<td><p>failure ratio</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Fult</code></td>
<td><p>ultimate (maximum) passive resistance*</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">gap</code></td>
<td><p>initial gap*</p></td>
</tr>
</tbody>
</table>
<p>NOTES:</p>
<ul>
<li>This material is implemented as a compression-only gap material.
<code class="tcl-variable">Fult</code> and <code class="tcl-variable">gap</code> should be input as
negative values.</li>
<li>Recomended Values:</li>
</ul>
<table>
<tbody>
<tr class="odd">
<td><code class="parameter-table-variable">Kmax</code></td>
<td><p>= 20300 kN/m of abutment width</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Kcur</code></td>
<td><p>= $Kmax</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Rf</code></td>
<td><p>= 0.7</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Fult</code></td>
<td><p>= -326 kN per meter of abutment width</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">gap</code></td>
<td><p>= -2.54 cm</p></td>
</tr>
</tbody>
</table>
<hr />
<p>DESCRIPTION:</p>
<p>This file contains the class implementation for
HyperbolicGapMaterial. This material is based on abutment stiffness
models for bridge simulation proposed by Patrick Wilson and Ahmed
Elgamal at UCSD. The abutment stiffness models are based on large-scale
abutment tests performed on the outdoor shaking table at UCSD. The model
is described for a 1.68 meter (5.5 ft) tall backwall height (typical
size) and a 1 meter wide section along the width of the abutment (to be
scaled accordingly). The hyperbolic force-displacement model is based on
work by Duncan and Mokwa (2001) and Shamsabadi et al. (2007) with
calibrated parameters from UCSD abutment tests. This model matches very
well with test data up to 7.64 cm of longitudinal displacement.</p>
<dl>
<dt></dt>
<dd>

$$F(x) = \frac{x}{\frac{1}{K_\text{max}} + R_f
\frac{x}{F_\text{ult}}}$$

</dd>
</dl>
<figure>
<img src="/OpenSeesRT/contrib/static/HyperbolicGapA.png" title="HyperbolicGapA.png"
alt="HyperbolicGapA.png" />
<figcaption aria-hidden="true">HyperbolicGapA.png</figcaption>
</figure>
<figure>
<img src="/OpenSeesRT/contrib/static/HyperbolicGapB.png" title="HyperbolicGapB.png"
alt="HyperbolicGapB.png" />
<figcaption aria-hidden="true">HyperbolicGapB.png</figcaption>
</figure>
<hr />
<p>REFERENCES:</p>
<p>Duncan, J. M., and Mokwa, R. L. (2001). "Passive earth pressures:
theories and tests." Journal of Geotechnical and Geoenvironmental
Engineering, 127(3), 248-257.</p>
<p>Shamsabadi, A., Rollins, K. M., and Kapuskar, M. (2007). "Nonlinear
soil-abutment-bridge structure interaction for seismic performance-based
design." Journal of Geotechnical and Geoenvironmental Engineering,
133(6), 707-720.</p>
<p>Wilson, P and Elgamal, A (2006). "Large scale measurement of lateral
earth pressure on bridge abutment back-wall subjected to static and
dynamic loading." Proceedings of the New Zealand Workshop on
Geotechnical Earthquake Engineering, University of Canterbury,
Christchurch, New Zealand: pp 307-315.</p>
<hr />
<p>Code Developed by: <span style="color:blue"> Mathew Dryden, UC
Berkeley</span> and <span style="color:blue"> Patrick
Wilson, UCSD</span></p>
