---
description: Modified Ibarra-Medina-Krawinkler Deterioration Model with Bilinear Hysteretic Response (Bilin Material)
...

# ModIMKBilin

<p>This command is used to construct a bilin material. The bilin
material simulates the modified Ibarra-Krawinkler deterioration model
with bilinear hysteretic response. Note that the hysteretic response of
this material has been calibrated with respect to more than 350
experimental data of steel beam-to-column connections and multivariate
regression formulas are provided to estimate the deterioration
parameters of the model for different connection types. These
relationships were developed by Lignos and Krawinkler (2009, 2011) and
have been adopted by PEER/ATC (2010). <strong>The input parameters for
this component model can be computed interactively from this [link: <a
href="http://resslabtools.epfl.ch/">http://resslabtools.epfl.ch/</a>].
Use the module <em>Component Model</em>.</strong></p>

```tcl
uniaxialMaterial Bilin $matTag $K0 $as_Plus $as_Neg
        $My_Plus $My_Neg $Lamda_S $Lamda_C $Lamda_A $Lamda_K $c_S $c_C $c_A $c_K
        $theta_p_Plus $theta_p_Neg $theta_pc_Plus $theta_pc_Neg $Res_Pos
        $Res_Neg $theta_u_Plus $theta_u_Neg $D_Plus $D_Neg
        &lt;$nFactor&gt;
```

<hr />
<table>
<tbody>
<tr class="odd">
<td><code class="parameter-table-variable">matTag</code></td>
<td><p>integer tag identifying material</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">K0</code></td>
<td><p>elastic stiffness</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">as_Plus</code></td>
<td><p>strain hardening ratio for positive loading direction</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">as_Neg</code></td>
<td><p>strain hardening ratio for negative loading direction</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">My_Plus</code></td>
<td><p>effective yield strength for positive loading direction</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">My_Neg</code></td>
<td><p>effective yield strength for negative loading direction (negative
value)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Lamda_S</code></td>
<td><p>Cyclic deterioration parameter for strength deterioration
[E_t=Lamda_S*M_y; set Lamda_S = 0 to disable this mode of
deterioration]</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Lamda_C</code></td>
<td><p>Cyclic deterioration parameter for post-capping strength
deterioration [E_t=Lamda_C*M_y; set Lamda_C = 0 to disable this mode of
deterioration]</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Lamda_A</code></td>
<td><p>Cyclic deterioration parameter for acceleration reloading
stiffness deterioration (is not a deterioration mode for a component
with Bilinear hysteretic response) [Input value is required, but not
used; set Lamda_A = 0].</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Lamda_K</code></td>
<td><p>Cyclic deterioration parameter for unloading stiffness
deterioration [E_t=Lamda_K*M_y; set Lamda_k = 0 to disable this mode of
deterioration]</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">c_S</code></td>
<td><p>rate of strength deterioration. The default value is
1.0.</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">c_C</code></td>
<td><p>rate of post-capping strength deterioration. The default value is
1.0.</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">c_A</code></td>
<td><p>rate of accelerated reloading deterioration. The default value is
1.0.</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">c_K</code></td>
<td><p>rate of unloading stiffness deterioration. The default value is
1.0.</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">theta_p_Plus</code></td>
<td><p>pre-capping rotation for positive loading direction (often noted
as plastic rotation capacity)</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">theta_p_Neg</code></td>
<td><p>pre-capping rotation for negative loading direction (often noted
as plastic rotation capacity) (positive value)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">theta_pc_Plus</code></td>
<td><p>post-capping rotation for positive loading direction</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">theta_pc_Neg</code></td>
<td><p>post-capping rotation for negative loading direction (positive
value)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">Res_Pos</code></td>
<td><p>residual strength ratio for positive loading direction</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">Res_Neg</code></td>
<td><p>residual strength ratio for negative loading direction (positive
value)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">theta_u_Plus</code></td>
<td><p>ultimate rotation capacity for positive loading
direction</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">theta_u_Neg</code></td>
<td><p>ultimate rotation capacity for negative loading direction
(positive value)</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">D_Plus</code></td>
<td><p>rate of cyclic deterioration in the positive loading direction
(this parameter is used to create assymetric hysteretic behavior for the
case of a composite beam). For symmetric hysteretic response use
1.0.</p></td>
</tr>
<tr class="even">
<td><code class="parameter-table-variable">D_Neg</code></td>
<td><p>rate of cyclic deterioration in the negative loading direction
(this parameter is used to create assymetric hysteretic behavior for the
case of a composite beam). For symmetric hysteretic response use
1.0.</p></td>
</tr>
<tr class="odd">
<td><code class="parameter-table-variable">nFactor</code></td>
<td><p>elastic stiffness amplification factor, mainly for use with
concentrated plastic hinge elements (optional, default = 0).</p></td>
</tr>
<tr class="even">
<td></td>
<td></td>
</tr>
</tbody>
</table>
<figure>
<img src="/OpenSeesRT/contrib/static/ModIKModel.png" title="ModIKModel.png" alt="ModIKModel.png" />
<figcaption aria-hidden="true">ModIKModel.PNG</figcaption>
</figure>
<p><strong>Image from: Lignos et al. (2011)</strong></p>
<p>The deterioration model parameters can be calibrated based on actual
experimental data of steel components. Instead, a user can determine the
same parameters with predictive equations that have been developed by
Lignos and Krawinkler (2009, 2011). These equations relate deterioration
modelling parameters with geometric and material properties of steel
components and have been developed with multivariate regression analysis
after extensive calibration of a recently developed steel component
database of more than 300 steel specimens (Lignos and Krawinkler 2007,
2009, 2011).</p>
<hr />
<p><strong>References</strong>:</p>
<table>
<tbody>
<tr class="odd">
<td><p><strong>[1]</strong></p></td>
<td><p>Ibarra L.F., and Krawinkler, H. (2005). “Global collapse of frame
structures under seismic excitations”, Rep. No. TB 152, The John A.
Blume Earthquake Engineering Center, Stanford University, Stanford,
CA.</p></td>
</tr>
<tr class="even">
<td><p><strong>[2]</strong></p></td>
<td><p>Ibarra L.F., Medina R. A., and Krawinkler H. (2005). “Hysteretic
models that incorporate strength and stiffness deterioration”,
Earthquake Engineering and Structural Dynamics, 34(12),
1489-1511.</p></td>
</tr>
<tr class="odd">
<td><p><strong>[3]</strong></p></td>
<td><p>Karavasilis T.L., Ricles J.M., Sause R. (2009). "Implementation
of deterioration elements in OpenSEES for collapse simulations" ATLSS
Engineering Research Center, Rep. No. 09-11.</p></td>
</tr>
<tr class="even">
<td><p><strong>[4]</strong></p></td>
<td><p>Lignos, D.G., and Krawinkler, H. (2007), “A database in support
of modeling of component deterioration for collapse prediction of steel
frame structures”, Proc. ASCE Structures Congress, Long Beach CA, SEI
institute.</p></td>
</tr>
<tr class="odd">
<td><p><strong>[5]</strong></p></td>
<td><p>Lignos, D.G. and Krawinkler, H. (2012). “Sidesway collapse of
deteriorating structural systems under seismic excitations,” Rep.No.TB
177, The John A. Blume Earthquake Engineering Research Center, Stanford
University, Stanford, CA. [electronic version: <a
href="https://blume.stanford.edu/tech_reports">https://blume.stanford.edu/tech_reports</a>]</p></td>
</tr>
<tr class="even">
<td><p><strong>[6]</strong></p></td>
<td><p>Lignos, D. G., Krawinkler, H. and Whittaker, A.S. (2011).
"Prediction and validation of sidesway collapse of two scale models of a
4-story steel moment frame", Earthquake Engineering and Structural
Dynamics, EESD, Vol. 40 (7), 807-825.</p></td>
</tr>
<tr class="odd">
<td><p><strong>[7]</strong></p></td>
<td><p>Lignos, D.G., and Krawinkler, H. (2010). “A steel database for
component deterioration of tubular hollow square steel columns under
varying axial load for collapse assessment of steel structures under
earthquakes”, Proc. 7th International Conference on Urban Earthquake
Engineering (7CUEE), March 3-5, Tokyo, Japan.</p></td>
</tr>
<tr class="even">
<td><p><strong>[8]</strong></p></td>
<td><p>Lignos, D.G., and Krawinkler, H. (2011). “Deterioration modeling
of steel components in support of collapse prediction of steel moment
frames under earthquake loading”, Journal of Structural Engineering,
ASCE, Vol. 137 (11), 1291-1302. <embed src="BilinMaterialOpenSees.pdf"
title="BilinMaterialOpenSees.pdf" /></p></td>
</tr>
<tr class="odd">
<td><p><strong>[9]</strong></p></td>
<td><p>PEER/ATC (2010). “Modeling and acceptance criteria for seismic
design and analysis of tall buildings”, PEER/ATC-72-1, prepared by the
Applied Technology Council in cooperation with the Pacific Earthquake
Engineering Research Center, Redwood City, CA..</p></td>
</tr>
<tr class="even">
<td><p><strong>[10]</strong></p></td>
<td><p>Lignos, D.G., Hartloper, A.R., Elkady, A.M.A., Deirlein, G.G.,
Hamburger, R. (2019). “Proposed Updates to the ASCE 41 Nonlinear
Modeling Parameters for Wide-Flange Steel Columns in Support of
Performance-Based Seismic Engineering”, Journal of Structural
Engineering, 04019083, <a
href="https://doi.org/10.1061/(ASCE)ST.1943-541X.0002353">https://doi.org/10.1061/(ASCE)ST.1943-541X.0002353</a>.</p></td>
</tr>
<tr class="odd">
<td></td>
<td></td>
</tr>
</tbody>
</table>
<p>Code Developed by : <span style="color:blue"> by Dr. Dimitrios
G. Lignos, McGill University and was implemented by Dr. Theodore
Karavasilis, Oxford University </span></p>
<p>nFactor Implemented by: <span style="color:blue"> by Dr. Andre
R. Barbosa, Oregon State University and Mr. Filipe L.A. Ribeiro,
Universidade Nova de Lisboa </span></p>
